@@ -14,12 +14,16 @@
 
 from typing import Optional
 
+from selenium.common.exceptions import UnknownMethodException
+
 from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
+from appium.protocols.webdriver.can_execute_scripts import CanExecuteScripts
+from appium.protocols.webdriver.can_remember_extension_presence import CanRememberExtensionPresence
 
 from ..mobilecommand import MobileCommand as Command
 
 
-class DeviceTime(CanExecuteCommands):
+class DeviceTime(CanExecuteCommands, CanExecuteScripts, CanRememberExtensionPresence):
     @property
     def device_time(self) -> str:
         """Returns the date and time from the device.
@@ -27,7 +31,12 @@ class DeviceTime(CanExecuteCommands):
         Return:
             str: The date and time
         """
-        return self.execute(Command.GET_DEVICE_TIME_GET, {})['value']
+        ext_name = 'mobile: getDeviceTime'
+        try:
+            return self.assert_extension_exists(ext_name).execute_script(ext_name)
+        except UnknownMethodException:
+            # TODO: Remove the fallback
+            return self.mark_extension_absence(ext_name).execute(Command.GET_DEVICE_TIME_GET, {})['value']
 
     def get_device_time(self, format: Optional[str] = None) -> str:
         """Returns the date and time from the device.
@@ -45,9 +54,15 @@ class DeviceTime(CanExecuteCommands):
         Return:
             str: The date and time
         """
+        ext_name = 'mobile: getDeviceTime'
         if format is None:
             return self.device_time
-        return self.execute(Command.GET_DEVICE_TIME_POST, {'format': format})['value']
+        try:
+            return self.assert_extension_exists(ext_name).execute_script(ext_name, {'format': format})
+        except UnknownMethodException:
+            return self.mark_extension_absence(ext_name).execute(Command.GET_DEVICE_TIME_POST, {'format': format})[
+                'value'
+            ]
 
     def _add_commands(self) -> None:
         # noinspection PyProtectedMember,PyUnresolvedReferences
