@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import warnings
 from typing import Callable, Dict, List, Optional, Union
 
 from selenium.webdriver.common.utils import keys_to_typing
@@ -112,7 +111,7 @@ class WebElement(SeleniumWebElement):
         #     by = By.CSS_SELECTOR
         #     value = '[name="%s"]' % value
 
-        return self._execute(RemoteCommand.FIND_CHILD_ELEMENT, {"using": by, "value": value})['value']
+        return self._execute(RemoteCommand.FIND_CHILD_ELEMENT, {'using': by, 'value': value})['value']
 
     def find_elements(self, by: str = AppiumBy.ID, value: Union[str, Dict, None] = None) -> List['WebElement']:
         """Find elements given a AppiumBy strategy and locator
@@ -142,7 +141,7 @@ class WebElement(SeleniumWebElement):
         #     by = By.CSS_SELECTOR
         #     value = '[name="%s"]' % value
 
-        return self._execute(RemoteCommand.FIND_CHILD_ELEMENTS, {"using": by, "value": value})['value']
+        return self._execute(RemoteCommand.FIND_CHILD_ELEMENTS, {'using': by, 'value': value})['value']
 
     def clear(self) -> 'WebElement':
         """Clears text.
@@ -159,33 +158,6 @@ class WebElement(SeleniumWebElement):
         self._execute(Command.CLEAR, data)
         return self
 
-    def set_text(self, keys: str = '') -> 'WebElement':
-        """Sends text to the element.
-        deprecated:: 2.8.1
-
-        Previous text is removed.
-        Android only.
-
-        Args:
-            keys: the text to be sent to the element.
-
-        Usage:
-            element.set_text('some text')
-
-        Returns:
-            `appium.webdriver.webelement.WebElement`
-        """
-        warnings.warn(
-            'The "setText" API is deprecated and will be removed in future versions. '
-            'Instead the "send_keys" API or W3C Actions can be used. '
-            'See https://github.com/appium/python-client/pull/831',
-            DeprecationWarning,
-        )
-
-        data = {'text': keys}
-        self._execute(Command.REPLACE_KEYS, data)
-        return self
-
     @property
     def location_in_view(self) -> Dict[str, int]:
         """Gets the location of an element relative to the view.
@@ -200,27 +172,6 @@ class WebElement(SeleniumWebElement):
         """
         return self._execute(Command.LOCATION_IN_VIEW)['value']
 
-    def set_value(self, value: str) -> 'WebElement':
-        """Set the value on this element in the application
-        deprecated:: 2.8.1
-
-        Args:
-            value: The value to be set
-
-        Returns:
-            `appium.webdriver.webelement.WebElement`
-        """
-        warnings.warn(
-            'The "setValue" API is deprecated and will be removed in future versions. '
-            'Instead the "send_keys" API or W3C Actions can be used. '
-            'See https://github.com/appium/python-client/pull/831',
-            DeprecationWarning,
-        )
-
-        data = {'text': value}
-        self._execute(Command.SET_IMMEDIATE_VALUE, data)
-        return self
-
     # Override
     def send_keys(self, *value: str) -> 'WebElement':
         """Simulates typing into the element.
